==> nextcloud-app-mail-2.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/cy_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Gwaith",
    "Personal" : "Personol",
    "Mail" : "E-bost",
    "Auto" : "Awto",
    "Name" : "Enw",
    "Password" : "Cyfrinair",
    "Manual" : "Â Llaw",
    "IMAP Settings" : "Gosodiadau IMAP",
    "IMAP Host" : "Gwesteiwr IMAP",
    "IMAP Security" : "Diogelwch IMAP",
    "None" : "Dim",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porth IMAP",
    "IMAP User" : "Defnyddiwr IMAP",
    "IMAP Password" : "Cyfrinair IMAP",
    "SMTP Settings" : "Gosodiadau SMTP",
    "SMTP Host" : "Gwesteiwr SMTP",
    "SMTP Security" : "Diogelwch SMTP",
    "SMTP Port" : "Porth SMTP",
    "SMTP User" : "Defnyddiwr SMTP",
    "SMTP Password" : "Cyfrinair SMTP",
    "Connecting" : "Yn cysylltu",
    "Save" : "Cadw",
    "Connect" : "Cysylltu",
    "Signature" : "Llofnod",
    "Mail server" : "Gweinydd e-bost",
    "Cancel" : "Diddymu",
    "Add mail account" : "Ychwanegu cyfrif post",
    "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd",
    "Subject" : "Pwnc",
    "Saving draft …" : "Yn cadw drafft …",
    "Draft saved" : "Cadwyd y drafft",
    "Upload attachment" : "Llwytho atodiad",
    "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
    "Uploading attachments …" : "Llwytho atodiadau ...",
    "Sending …" : "Anfon",
    "Error sending your message" : "Gwall wrth anfon eich neges",
    "Go back" : "Nôl",
    "Retry" : "Ceisio eto",
    "Message sent!" : "Neges wedi'i hanfon!",
    "Send" : "Anfon",
    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
    "Draft: " : "Drafft:",
    "Favorite" : "Ffefryn",
    "Select" : "Select",
    "Move" : "Symud",
    "Create event" : "Creu digwyddiad",
    "Report this bug" : "Cofnodi'r gwall",
    "All day" : "Drwy'r dydd",
    "Create" : "Creu",
    "Accept" : "Derbyn",
    "Decline" : "Gwrthod",
    "Choose" : "Dewisa",
    "Other" : "Arall",
    "Import into calendar" : "Mewnforio i'r calendr",
    "Download attachment" : "Llwytho'r atodiad i lawr",
    "Save to Files" : "Cadw i Ffeiliau",
    "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
    "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
    "Choose a folder to store the attachments in" : "Dewiswch ffolder i gadw'r atodiadau ynddi",
    "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
    "Remove account" : "Dileu cyfrif",
    "Loading …" : "Yn llwytho …",
    "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
    "Edit name" : "Golygu enw",
    "New message" : "Neges newydd",
    "No message selected" : "Dim neges wedi'i dewis",
    "Delete" : "Dileu",
    "Add" : "Ychwanegu",
    "Disabled" : "Analluogwyd",
    "Enabled" : "Galluogwyd",
    "Custom" : "Cyfaddas",
    "Not found" : "Heb ei ganfod",
    "Remove" : "Gwaredu",
    "(organizer)" : "(trefnydd)",
    "Untitled event" : "Digwyddiad di-deitl",
    "General" : "Cyffredinol",
    "User" : "User",
    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
    "Speed up your Mail experience with these quick shortcuts." : "Cyflymwch eich profiad E-bost gyda'r llwybrau byr cyflym hyn.",
    "Compose new message" : "Ysgrifennu Neges _Newydd",
    "Newer message" : "Neges diweddarach",
    "Older message" : "Neges hyn",
    "Toggle star" : "Toglo seren",
    "Toggle unread" : "Toglo heb ei darllen",
    "Search" : "Chwilio",
    "Refresh" : "Ail-lwytho",
    "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
    "All" : "Popeth",
    "Archive" : "Archif",
    "Drafts" : "Drafftiau",
    "Favorites" : "Ffefrynnau",
    "All inboxes" : "Pob blwch derbyn",
    "Inbox" : "Blwch Derbyn",
    "Junk" : "Sothach",
    "Sent" : "Anfonwyd",
    "Trash" : "Sbwriel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["oddi wrth {from}","oddi wrth {from}","oddi wrth {from}","oddi wrth {from}"],
    "Nextcloud Mail" : "E-bost Nextcloud",
    "Could not load {tag}{name}{endtag}" : "Methu llwytho {tag} {name} {endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Bu anhawster wrth lwytho {tag}{name}{endtag}",
    "Could not load your message" : "Methu llwytho'ch neges",
    "Could not load the desired message" : "Methu llwytho'r neges a ddewiswyd",
    "Could not load the message" : "Methu llwytho'r neges",
    "Error loading message" : "Gwall wrth lwytho neges",
    "Forwarding to %s" : "Anfon ymlaen at %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
    "Redirect" : "Ailgyfeirio",
    "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
    "Continue to %s" : "Parhau i %s"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> nextcloud-app-mail-4.1.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/cy_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Gwaith",
    "Personal" : "Personol",
    "Mail" : "E-bost",
    "Auto" : "Awto",
    "Name" : "Enw",
    "Password" : "Cyfrinair",
    "Manual" : "Â Llaw",
    "IMAP Settings" : "Gosodiadau IMAP",
    "IMAP Host" : "Gwesteiwr IMAP",
    "IMAP Security" : "Diogelwch IMAP",
    "None" : "Dim",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porth IMAP",
    "IMAP User" : "Defnyddiwr IMAP",
    "IMAP Password" : "Cyfrinair IMAP",
    "SMTP Settings" : "Gosodiadau SMTP",
    "SMTP Host" : "Gwesteiwr SMTP",
    "SMTP Security" : "Diogelwch SMTP",
    "SMTP Port" : "Porth SMTP",
    "SMTP User" : "Defnyddiwr SMTP",
    "SMTP Password" : "Cyfrinair SMTP",
    "Connecting" : "Yn cysylltu",
    "Save" : "Cadw",
    "Connect" : "Cysylltu",
    "Signature" : "Llofnod",
    "Mail server" : "Gweinydd e-bost",
    "Go back" : "Nôl",
    "Email address" : "Cyfeiriad e-bost",
    "Cancel" : "Diddymu",
    "Add mail account" : "Ychwanegu cyfrif post",
    "General" : "Cyffredinol",
    "List" : "Rhestr",
    "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
    "Register" : "Cofrestru",
    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
    "Compose new message" : "Ysgrifennu Neges _Newydd",
    "Newer message" : "Neges diweddarach",
    "Older message" : "Neges hyn",
    "Toggle star" : "Toglo seren",
    "Toggle unread" : "Toglo heb ei darllen",
    "Archive" : "Archif",
    "Delete" : "Dileu",
    "Search" : "Chwilio",
    "Send" : "Anfon",
    "Refresh" : "Ail-lwytho",
    "Subject" : "Pwnc",
    "Saving draft …" : "Yn cadw drafft …",
    "Draft saved" : "Cadwyd y drafft",
    "Upload attachment" : "Llwytho atodiad",
    "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
    "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
    "Choose" : "Dewisa",
    "Confirm" : "Cadarnhau",
    "Draft: " : "Drafft:",
    "Favorite" : "Ffefryn",
    "Back" : "Nôl",
    "Create event" : "Creu digwyddiad",
    "Report this bug" : "Cofnodi'r gwall",
    "All day" : "Drwy'r dydd",
    "Description" : "Disgrifiad",
    "Create" : "Creu",
    "Select" : "Select",
    "Comment" : "Sylw",
    "Accept" : "Derbyn",
    "Decline" : "Gwrthod",
    "Remove" : "Gwaredu",
    "Other" : "Arall",
    "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
    "Import into calendar" : "Mewnforio i'r calendr",
    "Download attachment" : "Llwytho'r atodiad i lawr",
    "Save to Files" : "Cadw i Ffeiliau",
    "Choose a folder to store the attachments in" : "Dewiswch ffolder i gadw'r atodiadau ynddi",
    "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
    "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
    "Move" : "Symud",
    "Remove account" : "Dileu cyfrif",
    "Loading …" : "Yn llwytho …",
    "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
    "Rename" : "Ailenwi",
    "New message" : "Neges newydd",
    "Error sending your message" : "Gwall wrth anfon eich neges",
    "Retry" : "Ceisio eto",
    "Uploading attachments …" : "Llwytho atodiadau ...",
    "Sending …" : "Anfon",
    "Add" : "Ychwanegu",
    "Close" : "Cau",
    "Date" : "Date",
    "Tags" : "Tagiau",
    "Custom" : "Cyfaddas",
    "Not found" : "Heb ei ganfod",
    "(organizer)" : "(trefnydd)",
    "Untitled event" : "Digwyddiad di-deitl",
    "Actions" : "Gweithredoedd",
    "User" : "User",
    "Certificate" : "Tystysgrif",
    "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
    "All" : "Popeth",
    "Drafts" : "Drafftiau",
    "Favorites" : "Ffefrynnau",
    "All inboxes" : "Pob blwch derbyn",
    "Inbox" : "Blwch Derbyn",
    "Junk" : "Sothach",
    "Sent" : "Anfonwyd",
    "Trash" : "Sbwriel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["oddi wrth {from}","oddi wrth {from}","oddi wrth {from}","oddi wrth {from}"],
    "Nextcloud Mail" : "E-bost Nextcloud",
    "Could not load {tag}{name}{endtag}" : "Methu llwytho {tag} {name} {endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Bu anhawster wrth lwytho {tag}{name}{endtag}",
    "Could not load your message" : "Methu llwytho'ch neges",
    "Could not load the desired message" : "Methu llwytho'r neges a ddewiswyd",
    "Could not load the message" : "Methu llwytho'r neges",
    "Error loading message" : "Gwall wrth lwytho neges",
    "Forwarding to %s" : "Anfon ymlaen at %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
    "Redirect" : "Ailgyfeirio",
    "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
    "Continue to %s" : "Parhau i %s"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
